==> vacuum-1.1.0.tar.xz: vacuum-1.1.0/src/translations/de/chatstates.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de" sourcelanguage="en">
<context>
    <name>ChatStates</name>
    <message>
        <source>Chat State Notifications</source>
        <translation>Chat Status Benachrichtigungen</translation>
    </message>
    <message>
        <source>Allow Chat State Notifications</source>
        <translation>Chat Status Benachrichtigungen zulassen</translation>
    </message>
    <message>
        <source>Disallow Chat State Notifications</source>
        <translation>Chat Status Benachrichtigungen verbieten</translation>
    </message>
    <message>
        <source>Allows to share information about the user&apos;s activity in the chat</source>
        <translation>Erlaubt das veröffentlichen von Informationen über die Aktivität des Benutzers</translation>
    </message>
    <message>
        <source>Supports the exchanging of the information about the user&apos;s activity in the chat</source>
        <translation>Stellt die Möglichkeit bereit, Informationen über die Aktivität des Benutzers auszutauschen</translation>
    </message>
    <message>
        <source>Send chat state notifications</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>StateWidget</name>
    <message>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Unbekannt</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Aktiv</translation>
    </message>
    <message>
        <source>Composing</source>
        <translation>Spreibt</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Pausiert</translation>
    </message>
    <message>
        <source>User chat status</source>
        <translation>Benutzer Chat Status</translation>
    </message>
    <message>
        <source>Always send</source>
        <translation>Immer senden</translation>
    </message>
    <message>
        <source>Never send</source>
        <translation>Niemals senden</translation>
    </message>
    <message>
        <source>Inactive %1</source>
        <translation>Inaktiv %1</translation>
    </message>
    <message>
        <source>Gone %1</source>
        <translation>Weg %1</translation>
    </message>
</context>
</TS>

==> vacuum-1.2.4.tar.xz: vacuum-1.2.4/src/translations/de/chatstates.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de" sourcelanguage="en">
<context>
    <name>ChatStates</name>
    <message>
        <source>Chat State Notifications</source>
        <translation>Chat Status Benachrichtigungen</translation>
    </message>
    <message>
        <source>Allow Chat State Notifications</source>
        <translation>Chat Status Benachrichtigungen einschalten</translation>
    </message>
    <message>
        <source>Disallow Chat State Notifications</source>
        <translation>Chat Status Benachrichtigungen abschalten</translation>
    </message>
    <message>
        <source>Allows to share information about the user&apos;s activity in the chat</source>
        <translation>Erlaubt das veröffentlichen von Informationen über die Aktivität des Benutzers</translation>
    </message>
    <message>
        <source>Supports the exchanging of the information about the user&apos;s activity in the chat</source>
        <translation>Stellt die Möglichkeit bereit, Informationen über die Aktivität des Benutzers im Chat auszutauschen</translation>
    </message>
    <message>
        <source>Send chat state notifications</source>
        <translation>Sende Chat Status Informationen</translation>
    </message>
    <message>
        <source>When contact is typing the message for you</source>
        <translation>Wenn der Kontakt eine Nachricht für sie schreibt</translation>
    </message>
    <message>
        <source>Typing a message...</source>
        <translation>Schreibt eine Nachricht ...</translation>
    </message>
</context>
<context>
    <name>StateWidget</name>
    <message>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Unbekannt</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Aktiv</translation>
    </message>
    <message>
        <source>Composing</source>
        <translation>Schreibt</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Pausiert</translation>
    </message>
    <message>
        <source>User chat status</source>
        <translation>Benutzer Chat Status</translation>
    </message>
    <message>
        <source>Always send</source>
        <translation>Immer senden</translation>
    </message>
    <message>
        <source>Never send</source>
        <translation>Niemals senden</translation>
    </message>
    <message>
        <source>Inactive %1</source>
        <translation>Inaktiv %1</translation>
    </message>
    <message>
        <source>Gone %1</source>
        <translation>Weg %1</translation>
    </message>
</context>
</TS>
